#!/bin/sh

prefix=/usr/local
$prefix/lib/pyink/pyink.py
